@@ -36,7 +36,12 @@ if FOAM_VERSION( ">=", "010700" ):
     from boundaryFlux.r1_7_0 import *
     pass
      
-     
+#--------------------------------------------------------------------------------------
+if FOAM_VERSION( ">=", "020000" ):
+    from boundaryFlux.r2_0_0 import *
+    pass
+    
+    
 #--------------------------------------------------------------------------------------
 def entry_point():
     try:
